Changelog
=========

0.3.5 (2015-06-06)
------------------
- Moved to github [veit]
- Plone 4.3 compatibility [veit] 

0.3.4 (2011-03-30)
------------------
- documentation update

0.3.3 (2010-12-03)
------------------
- Added Spanish translation [hvelarde]
- Some basic tests were added [hvelarde]

0.3.2 (2010-11-12)
------------------
- Removed unused adapter override [micecchi]

0.3.1 (2010-11-09)
------------------
- Fixed dashboardManager archetype and set adding permission [micecchi]

0.3.0 (2010-09-20)
------------------
- Created a new object that extends portlet pages, but doesn't change their features [micecchi]
- Fixed portlet provider interfaces. Now  you can add only the portlet of dashboard-manager [micecchi]
- Fixed assignment copy. Now the portlets are deep-copied in user's dashboard and not simply assigned.
  In this way when an user modify one portlet in his dashboard, this change doesn't affect other user's portlets. [micecchi]  

0.2.9 (2010-08-06)
------------------
- improved error handling

0.2.8 (2010-08-05)
------------------
- i18n update
- some fixes
- documentation update

0.2.7 (2010-08-02)
------------------
- preliminary German translation
- simple UI for the removal of portlets from arbitrary user
  dashboards

0.2.6 (2010-07-30)
------------------
- auto-completion for group filter

0.2.5 (2010-07-30)
------------------
- added simple dashboard introspection for a single user
  or all users of a group

0.2.4 (2010-07-30)
------------------
- better PAS integration

0.2.3 (2010-07-30)
------------------
- group filter now working with LDAP

0.2.2 (2010-07-29)
------------------
- filtering for group

0.2.1 (2010-07-27)
------------------
- fixed retrieval of group members in assignment code

0.2.0 (2010-07-27)
------------------
- Plone 4 compatibility

0.1.5 (2010-07-27)
------------------
- disabled @@my-dashboard-pages view
- minor cleanup

0.1.4 (2010-07-27)
------------------
- UI tweak
- more i18n

0.1.3 (2010-07-27)
------------------
- some UI tweak
- icon for control panel

0.1.2 (2010-07-27)
------------------
- i18n
- code cleanup
- moving from roles to groups
- removed virtual groups from selections
- some cleanup
- logger support
- rephrasing of texts

0.1.1 (2010-07-26)
------------------
- skin cleanup

0.1.0 (2010-07-26)
------------------

- Initial release
